Defined as
$$\sum_{i=1}^n \chi^2_{k_i}(p_i) > \chi^2_{\sum{k_i}}(\alpha)$$
If k is a single value it is used for all the p
of which there are n.
If any value of \(k<1\) then the corresponding p
is not included.
The values of \(p\) should be such that
\(0<p\le{}1\) and a warning is given if that
is not true.
An error is given
if possibly as a result of deletions
fewer than two studies remain.
The plot method for class ‘metap’
calls schweder on the valid
\(p\)-values.
Inspection of the distribution of \(p\)-values is highly recommended
as extreme values in opposite directions do not always
cancel out especially for small values of k.
See last example.
This may not be what you want.